@@ -1,8 +1,10 @@
+from http.cookiejar import CookieJar
 from re import search
 from time import perf_counter
 from time import sleep
 from typing import Any
 from typing import Optional
+from typing import Union
 
 from .connection import CloudflareScraper
 from .connection import Response
@@ -17,6 +19,7 @@ from .journal import Journal
 from .parse import BeautifulSoup
 from .parse import check_page
 from .parse import check_page_raise
+from .parse import parse_loggedin_user
 from .parse import parse_page
 from .parse import parse_search_submissions
 from .parse import parse_user_favorites
@@ -31,17 +34,15 @@ from .user import UserPartial
 
 
 class FAAPI:
-    def __init__(self, cookies: list[dict[str, Any]] = None):
-        self.cookies: list[dict[str, Any]] = cookies or []
-        self.session: CloudflareScraper = make_session(self.cookies)
+    def __init__(self, cookies: Union[list[dict[str, str]], CookieJar] = None):
+        self.session: CloudflareScraper = make_session(cookies or [])
         self.robots: dict[str, list[str]] = get_robots()
         self.crawl_delay: float = float(self.robots.get("Crawl-delay", [1.0])[0])
         self.last_get: float = perf_counter() - self.crawl_delay
         self.raise_for_delay: bool = False
 
-    def load_cookies(self, cookies: list[dict[str, Any]]):
-        self.cookies = cookies
-        self.session = make_session(self.cookies)
+    def load_cookies(self, cookies: Union[list[dict[str, str]], CookieJar]):
+        self.session = make_session(cookies)
 
     def handle_delay(self):
         if (delay_diff := perf_counter() - self.last_get) < self.crawl_delay:
@@ -62,6 +63,10 @@ class FAAPI:
         except ConnectionError:
             return False
 
+    @property
+    def login_status(self) -> bool:
+        return parse_loggedin_user(self.get_parsed("login")) is not None
+
     def get(self, path: str, **params) -> Response:
         self.check_path(path)
         self.handle_delay()
@@ -72,6 +77,9 @@ class FAAPI:
         response.raise_for_status()
         return parse_page(response.text) if response.ok else None
 
+    def me(self) -> Optional[User]:
+        return self.user(user) if (user := parse_loggedin_user(self.get_parsed("login"))) else None
+
     def submission(self, submission_id: int, get_file: bool = False) -> tuple[Submission, Optional[bytes]]:
         sub: Submission = Submission(self.get_parsed(join_url("view", int(submission_id))))
         sub_file: Optional[bytes] = self.submission_file(sub) if get_file and sub.id else None
