@@ -37,7 +37,7 @@ class Journal:
         yield "mentions", self.mentions
 
     def __repr__(self):
-        return repr(dict(self))
+        return self.__str__()
 
     def __str__(self):
         return f"{self.id} {self.author} {self.title}"
