@@ -23,7 +23,7 @@ class SubmissionBase:
         yield "author", dict(self.author)
 
     def __repr__(self):
-        return repr(dict(self))
+        return self.__str__()
 
     def __str__(self):
         return f"{self.id} {self.author} {self.title}"
